diff --git a/Doxyfile b/Doxyfile
index ff45a5d75008ebe74ae2aaf1d6affc75bf686d6d..f32ef3de7315258e1b5aac427419dce4eec7f00d 100644
--- a/Doxyfile
+++ b/Doxyfile
@@ -1964,7 +1964,7 @@ PREDEFINED             =
 EXPAND_AS_DEFINED      =
 
 # If the SKIP_FUNCTION_MACROS tag is set to YES then doxygen's preprocessor will
-# remove all refrences to function-like macros that are alone on a line, have an
+# remove all references to function-like macros that are alone on a line, have an
 # all uppercase name, and do not end with a semicolon. Such function macros are
 # typically used for boiler-plate code, and will confuse the parser if not
 # removed.
diff --git a/NEWS b/NEWS
index da532d3cf566dad0b581c2d665e5c70b7c108f0d..5dde2cfe0eb0e59d8d36a94fcd0e4ac7ae4fc934 100644
--- a/NEWS
+++ b/NEWS
@@ -40,13 +40,13 @@ Bugfixes:
 ---------
  - DNSSEC: Allow import of duplicate private key into the KASP
  - DNSSEC: Avoid duplicate NSEC for Wildcard No Data answer
- - Fix server crash when an incomming transfer is in progress and reload is issued
+ - Fix server crash when an incoming transfer is in progress and reload is issued
  - Fix socket polling when configured with many interfaces and threads
  - Fix compilation against Nettle 3.2
 
 Improvements:
 -------------
- - Select correct source address for UDP messages recieved on ANY address
+ - Select correct source address for UDP messages received on ANY address
  - Extend documentation of knotc commands
 
 Knot DNS 2.1.0 (2016-01-14)
@@ -253,7 +253,7 @@ Knot DNS 1.5.2 (2014-09-08)
 Bugfixes:
 ---------
  - Some RR parsing corner cases were not handled properly
- - AXFR-style IXFR was refused and had to be retransfered
+ - AXFR-style IXFR was refused and had to be retransferred
  - Hash character (#) was not properly escaped when storing text zone file
 
 Knot DNS 1.5.1 (2014-08-19)
@@ -391,7 +391,7 @@ Bugfixes:
  - Journal race condition
  - Notifies are sent immediately
  - Crash in particular additionals processing
- - Race condition in event cancelation
+ - Race condition in event cancellation
  - Journal corruption after failed transactions
  - DNSSEC: fixed detection of ECDSA support
  - Refactored zone loading
@@ -801,5 +801,5 @@ Known issues:
  - RRSet rotation not implmented
  - Dynamic update support
  - IXFR code might be flaky sometimes
- - IXFR may be slow when too much (10 000+) RRSets are transfered at
+ - IXFR may be slow when too much (10 000+) RRSets are transferred at
    once
diff --git a/doc/operation.rst b/doc/operation.rst
index 5e4749f2591a2e5beb96105923261f3f5b8ebf8b..589c15a5d3038ed43a766f6903f3e2a7131d8ef0 100644
--- a/doc/operation.rst
+++ b/doc/operation.rst
@@ -92,7 +92,7 @@ to get all section identifiers or to get a specific configuration item::
 
 Modifying operations require an active configuration database transaction.
 Just one transaction can be active at a time. Such a transaction then can
-be aborted or commited. A semantic check is executed automatically before
+be aborted or committed. A semantic check is executed automatically before
 every commit::
 
     $ knotc conf-begin
diff --git a/src/contrib/dnstap/dnstap.proto b/src/contrib/dnstap/dnstap.proto
index 1ed1bb00e2f9acec085870c7313d03191aaa89a9..22784cd0691b92ff2964181cd13234c361366aa2 100644
--- a/src/contrib/dnstap/dnstap.proto
+++ b/src/contrib/dnstap/dnstap.proto
@@ -105,7 +105,7 @@ message Message {
 
     enum Type {
         // AUTH_QUERY is a DNS query message received from a resolver by an
-        // authoritative name server, from the perspective of the authorative
+        // authoritative name server, from the perspective of the authoritative
         // name server.
         AUTH_QUERY = 1;
 
diff --git a/src/contrib/hat-trie/hat-trie.c b/src/contrib/hat-trie/hat-trie.c
index b52383a7da625bd4b8330a2ec750eac245a43d99..f0ba061f9ea2402ee53ea49cf594d1cc8d15e70d 100644
--- a/src/contrib/hat-trie/hat-trie.c
+++ b/src/contrib/hat-trie/hat-trie.c
@@ -475,7 +475,7 @@ int hattrie_apply_rev_ahtable(hattrie_t* T, int (*f)(void*,void*), void* d)
 int hattrie_split_mid(node_ptr node, unsigned *left_m, unsigned *right_m)
 {
     /* count the number of occourances of every leading character */
-    unsigned int cs[NODE_CHILDS]; // occurance count for leading chars
+    unsigned int cs[NODE_CHILDS]; // occurrence count for leading chars
     memset(cs, 0, NODE_CHILDS * sizeof(unsigned int));
     uint16_t len;
     const char* key;
diff --git a/src/contrib/lmdb/mdb.c b/src/contrib/lmdb/mdb.c
index d2e81e4e9c541569279bddcee5d97c9a9ef24fb1..25b44a5f4d7f750d30dbc3270b549b6b1a17128b 100644
--- a/src/contrib/lmdb/mdb.c
+++ b/src/contrib/lmdb/mdb.c
@@ -475,7 +475,7 @@ static txnid_t mdb_debug_start;
 	 *	The string is printed literally, with no format processing.
 	 */
 #define DPUTS(arg)	DPRINTF(("%s", arg))
-	/** Debuging output value of a cursor DBI: Negative in a sub-cursor. */
+	/** Debugging output value of a cursor DBI: Negative in a sub-cursor. */
 #define DDBI(mc) \
 	(((mc)->mc_flags & C_SUB) ? -(int)(mc)->mc_dbi : (int)(mc)->mc_dbi)
 /** @} */
diff --git a/src/contrib/ucw/binsearch.h b/src/contrib/ucw/binsearch.h
index dffcd1f996e738c159eda39e0c723022d54da84b..5a48b11dbf23e55ec478bc4f8481b8d384636046 100644
--- a/src/contrib/ucw/binsearch.h
+++ b/src/contrib/ucw/binsearch.h
@@ -34,17 +34,17 @@
 })
 
 /**
- * The default comparision macro for @BIN_SEARCH_FIRST_GE_CMP().
+ * The default comparison macro for @BIN_SEARCH_FIRST_GE_CMP().
  **/
 #define ARY_LT_NUM(ary,i,x) (ary)[i] < (x)
 
 /**
- * Same as @BIN_SEARCH_FIRST_GE_CMP(), but uses the default `<` operator for comparisions.
+ * Same as @BIN_SEARCH_FIRST_GE_CMP(), but uses the default `<` operator for comparisons.
  **/
 #define BIN_SEARCH_FIRST_GE(ary,N,x) BIN_SEARCH_FIRST_GE_CMP(ary,N,ARY_LT_NUM,x)
 
 /**
- * Search the sorted array @ary of @N elements (non-decreasing) for the first occurence of @x.
- * Returns the index or -1 if no such element exists. Uses the `<` operator for comparisions.
+ * Search the sorted array @ary of @N elements (non-decreasing) for the first occurrence of @x.
+ * Returns the index or -1 if no such element exists. Uses the `<` operator for comparisons.
  **/
 #define BIN_SEARCH_EQ(ary,N,x) ({ int i = BIN_SEARCH_FIRST_GE(ary,N,x); if (i >= (N) || (ary)[i] != (x)) i=-1; i; })
diff --git a/src/dnssec/Doxyfile b/src/dnssec/Doxyfile
index 8b367ee58c0146d742b88109c96b40034dda38f2..8a0f63ee2bdf3abb1f1fbd1682c93b126e8f4dc0 100644
--- a/src/dnssec/Doxyfile
+++ b/src/dnssec/Doxyfile
@@ -1947,7 +1947,7 @@ PREDEFINED             =
 EXPAND_AS_DEFINED      =
 
 # If the SKIP_FUNCTION_MACROS tag is set to YES then doxygen's preprocessor will
-# remove all refrences to function-like macros that are alone on a line, have an
+# remove all references to function-like macros that are alone on a line, have an
 # all uppercase name, and do not end with a semicolon. Such function macros are
 # typically used for boiler-plate code, and will confuse the parser if not
 # removed.
diff --git a/src/dnssec/lib/dnssec/key.h b/src/dnssec/lib/dnssec/key.h
index 7343f7b7e557443820f2c595713d48f07958708b..8403b699f66d172db525342b9222cbcc9ff954ae 100644
--- a/src/dnssec/lib/dnssec/key.h
+++ b/src/dnssec/lib/dnssec/key.h
@@ -251,7 +251,7 @@ int dnssec_algorithm_key_size_range(dnssec_key_algorithm_t algorithm,
 				    unsigned *min, unsigned *max);
 
 /*!
- * Check if the private key size matches DNSKEY contraints.
+ * Check if the private key size matches DNSKEY constraints.
  *
  * \param algorithm  DNSKEY algorithm.
  * \param bits       Private key size.
diff --git a/src/dnssec/lib/kasp/dir/zone.c b/src/dnssec/lib/kasp/dir/zone.c
index 145b8cc24272af9bde407e113585fd15c6782594..f4a09717c527025a2d00984d77e8063a248b6bd1 100644
--- a/src/dnssec/lib/kasp/dir/zone.c
+++ b/src/dnssec/lib/kasp/dir/zone.c
@@ -30,7 +30,7 @@
 /* -- key parameters ------------------------------------------------------- */
 
 /*!
- * Key parameters as writting in zone config file.
+ * Key parameters as writing in zone config file.
  */
 struct key_params {
 	char *id;
diff --git a/src/dnssec/shared/bignum.h b/src/dnssec/shared/bignum.h
index 69cdce84bdc9931b40b80be16f12f17321c295ac..3576fbfa9056689919539b1a6a985cfcc84e78e1 100644
--- a/src/dnssec/shared/bignum.h
+++ b/src/dnssec/shared/bignum.h
@@ -35,6 +35,6 @@ size_t bignum_size_s(const dnssec_binary_t *value);
 /*!
  * Write unsigned number on a fixed width in a big-endian byte order.
  *
- * The destination size has to be set properly to accomodate used encoding.
+ * The destination size has to be set properly to accommodate used encoding.
  */
 void bignum_write(dnssec_binary_t *dest, const dnssec_binary_t *value);
diff --git a/src/dnssec/utils/keymgr.c b/src/dnssec/utils/keymgr.c
index 59b44829138efd3e248590bd557346628ebe6296..1dc25a6e76e1ba184481827251e01ab153795c2e 100644
--- a/src/dnssec/utils/keymgr.c
+++ b/src/dnssec/utils/keymgr.c
@@ -667,7 +667,7 @@ static int cmd_zone_add(int argc, char *argv[])
 
 	int r = dnssec_kasp_zone_exists(kasp, zone_name);
 	if (r == DNSSEC_EOK) {
-		error("Zone with given name alredy exists.");
+		error("Zone with given name already exists.");
 		return 1;
 	} else if (r != DNSSEC_NOT_FOUND) {
 		error("Failed to check if given zone exists (%s).", dnssec_strerror(r));
diff --git a/src/knot/dnssec/rrset-sign.c b/src/knot/dnssec/rrset-sign.c
index 6b1a536ba2f9cb58902a6a7f04141865d0f62ba1..0f1433bad96c53c80242e63eed02699e3d1bd5bd 100644
--- a/src/knot/dnssec/rrset-sign.c
+++ b/src/knot/dnssec/rrset-sign.c
@@ -224,7 +224,7 @@ static int sign_ctx_add_data(dnssec_sign_ctx_t *ctx,
  * \param[in]  sig_incepted  Timestamp of signature inception.
  * \param[in]  sig_expires   Timestamp of signature expiration.
  *
- * \return Error code, KNOT_EOK if succesful.
+ * \return Error code, KNOT_EOK if successful.
  */
 static int rrsigs_create_rdata(knot_rrset_t *rrsigs, dnssec_sign_ctx_t *ctx,
                                const knot_rrset_t *covered,
diff --git a/src/knot/dnssec/zone-sign.c b/src/knot/dnssec/zone-sign.c
index b144c77dbfcb410ad1d15e050967097f52662643..04e35d267518d43aca3290ae853e2a41e5237bbb 100644
--- a/src/knot/dnssec/zone-sign.c
+++ b/src/knot/dnssec/zone-sign.c
@@ -1071,7 +1071,7 @@ static int sign_changeset_wrap(knot_rrset_t *chg_rrset, changeset_signing_data_t
 			/*
 			 * If RRSet in zone DOES have RRSIGs although we
 			 * should not sign it, DDNS-caused change to node/rr
-			 * occured and we have to drop all RRSIGs.
+			 * occurred and we have to drop all RRSIGs.
 			 *
 			 * OR
 			 *
diff --git a/src/knot/modules/synth_record.c b/src/knot/modules/synth_record.c
index a4dc230f83508882c3429ea49d75dde7a786124a..5e63d62ac2a6394015ecee8a412daff057498e5e 100644
--- a/src/knot/modules/synth_record.c
+++ b/src/knot/modules/synth_record.c
@@ -115,7 +115,7 @@ typedef struct synth_template {
 	int mask;
 } synth_template_t;
 
-/*! \brief Substitute all occurences of given character. */
+/*! \brief Substitute all occurrences of given character. */
 static void str_subst(char *str, size_t len, char from, char to)
 {
 	for (int i = 0; i < len; ++i) {
diff --git a/src/knot/nameserver/chaos.c b/src/knot/nameserver/chaos.c
index e1312c943a899793a7db9613b0dbbe77dc7dc62a..b788b2e7aeffb1d29b657ebe8af6c306c57249a7 100644
--- a/src/knot/nameserver/chaos.c
+++ b/src/knot/nameserver/chaos.c
@@ -95,7 +95,7 @@ static int create_txt_rrset(knot_rrset_t *rrset, const knot_dname_t *owner,
 /*!
  * \brief Create a response for a TXT CHAOS query.
  *
- * \param return KNOT_RCODE_NOERROR if the response was succesfully created,
+ * \param return KNOT_RCODE_NOERROR if the response was successfully created,
  *               otherwise an RCODE representing the failure.
  */
 static int answer_txt(knot_pkt_t *response)
diff --git a/src/knot/nameserver/nsec_proofs.c b/src/knot/nameserver/nsec_proofs.c
index e118a8f3107a14e9f486648bc0f146a312afb675..0670ff852d94867a1b7b3493e8315f8886e6d3c4 100644
--- a/src/knot/nameserver/nsec_proofs.c
+++ b/src/knot/nameserver/nsec_proofs.c
@@ -40,7 +40,7 @@
  * \param name Domain name to create the 'next closer' name to.
  *
  * \return 'Next closer name' to the given domain name or NULL if an error
- *         occured.
+ *         occurred.
  */
 static knot_dname_t *ns_next_closer(const knot_dname_t *closest_encloser,
                                       const knot_dname_t *name)
@@ -98,7 +98,7 @@ static int ns_put_nsec3_from_node(const zone_node_t *node,
  * \param resp Response where to add the RRSets.
  *
  * \retval KNOT_EOK
- * \retval NS_ERR_SERVFAIL if a runtime collision occured. The server should
+ * \retval NS_ERR_SERVFAIL if a runtime collision occurred. The server should
  *                         respond with SERVFAIL in such case.
  */
 static int ns_put_covering_nsec3(const zone_contents_t *zone,
@@ -214,7 +214,7 @@ static int ns_put_nsec3_closest_encloser_proof(
  *
  * \param name Domain name to get the wildcard child name of.
  *
- * \return Wildcard child name or NULL if an error occured.
+ * \return Wildcard child name or NULL if an error occurred.
  */
 static knot_dname_t *ns_wildcard_child_name(const knot_dname_t *name)
 {
diff --git a/src/knot/server/journal.c b/src/knot/server/journal.c
index a8e3a7fb6b73a3ad7a9ecf7f508e7ec7d135991c..22faf20540d699b822615995fd522911770f4c34 100644
--- a/src/knot/server/journal.c
+++ b/src/knot/server/journal.c
@@ -849,7 +849,7 @@ static int changeset_pack(const changeset_t *chs, journal_t *j)
 	/* Serialize changeset, saving it bit by bit. */
 	ret = serialize_and_store_chgset(chs, journal_entry, entry_size);
 	/* Unmap the journal entry.
-	 * If successfuly written changeset to journal, validate the entry. */
+	 * If successfully written changeset to journal, validate the entry. */
 	int unmap_ret = journal_unmap(j, k, journal_entry, ret == KNOT_EOK);
 	if (ret == KNOT_EOK && unmap_ret != KNOT_EOK) {
 		ret = unmap_ret; /* Propagate the result. */
diff --git a/src/knot/server/udp-handler.c b/src/knot/server/udp-handler.c
index bcdf3c0101b21cbee61500b3971b3d4235635147..79d58b4d0d11685647be24980ca5ec97827ee031 100644
--- a/src/knot/server/udp-handler.c
+++ b/src/knot/server/udp-handler.c
@@ -93,7 +93,7 @@ static void udp_handle(udp_context_t *udp, int fd, struct sockaddr_storage *ss,
 		state = knot_overlay_produce(&udp->overlay, ans);
 	}
 
-	/* Send response only if finished successfuly. */
+	/* Send response only if finished successfully. */
 	if (state == KNOT_STATE_DONE) {
 		tx->iov_len = ans->size;
 	} else {
diff --git a/src/knot/zone/contents.c b/src/knot/zone/contents.c
index 48124b1769ad78eb02a2a6d5e8b37016a385873d..a35d7f56a2615689da485b2b7b633661e5f12e18 100644
--- a/src/knot/zone/contents.c
+++ b/src/knot/zone/contents.c
@@ -490,7 +490,7 @@ static int add_nsec3_node(zone_contents_t *zone, zone_node_t *node)
 		}
 	}
 
-	// how to know if this is successfull??
+	// how to know if this is successful??
 	ret = zone_tree_insert(zone->nsec3_nodes, node);
 	if (ret != KNOT_EOK) {
 		return ret;
diff --git a/src/knot/zone/events/events.h b/src/knot/zone/events/events.h
index 9552cfa33324655ce84992444520e5efdb4e9d34..0de33cbf9dab70db0449098d1274027cce4a8ba0 100644
--- a/src/knot/zone/events/events.h
+++ b/src/knot/zone/events/events.h
@@ -156,7 +156,7 @@ void zone_events_freeze(struct zone *zone);
 void zone_events_start(struct zone *zone);
 
 /*!
- * \brief Return time of the occurence of the given event.
+ * \brief Return time of the occurrence of the given event.
  *
  * \param zone  Zone to get event time from.
  * \param type  Event type.
diff --git a/src/knot/zone/node.c b/src/knot/zone/node.c
index a2c012bbb6e6c7b8e2c125fd7eaa2f97ecf47881..8fb1b9d3e71e6cb7663b936511c875356494d26b 100644
--- a/src/knot/zone/node.c
+++ b/src/knot/zone/node.c
@@ -92,7 +92,7 @@ zone_node_t *node_new(const knot_dname_t *owner, knot_mm_t *mm)
 		}
 	}
 
-	// Node is authoritive by default.
+	// Node is authoritative by default.
 	ret->flags = NODE_FLAGS_AUTH;
 
 	return ret;
diff --git a/src/knot/zone/node.h b/src/knot/zone/node.h
index 1ea16a99ab901cf0c00e70ccc4390482e3683278..9ed19273efe5318d531465ed526bfe5b4af25454 100644
--- a/src/knot/zone/node.h
+++ b/src/knot/zone/node.h
@@ -83,7 +83,7 @@ enum node_flags {
  * \param owner  Node's owner, will be duplicated.
  * \param mm     Memory context to use.
  *
- * \return Newly created node or NULL if an error occured.
+ * \return Newly created node or NULL if an error occurred.
  */
 zone_node_t *node_new(const knot_dname_t *owner, knot_mm_t *mm);
 
diff --git a/src/knot/zone/semantic-check.c b/src/knot/zone/semantic-check.c
index 90d81c78481a749bb6a7b4bc07853e6c5bba5cbb..0cdddf429dbfa0566ef64a0cde130b836d47052f 100644
--- a/src/knot/zone/semantic-check.c
+++ b/src/knot/zone/semantic-check.c
@@ -106,7 +106,7 @@ static char *error_messages[(-ZC_ERR_UNKNOWN) + 1] = {
 	"DNAME, wildcard pointing to itself",
 
 	/* ^
-	   | Important errors (to be logged on first occurence and counted) */
+	   | Important errors (to be logged on first occurrence and counted) */
 
 	/* Below are errors of lesser importance, to be counted unless
 	   specified otherwise */
diff --git a/src/knot/zone/zone-diff.c b/src/knot/zone/zone-diff.c
index 4ee0cdc89889ddb34ca138bfb99a961ff467f8dc..9a135146859a0310575c3c6f33bdb997b7f39b84 100644
--- a/src/knot/zone/zone-diff.c
+++ b/src/knot/zone/zone-diff.c
@@ -263,7 +263,7 @@ static int knot_zone_diff_node(zone_node_t **node_ptr, void *data)
 		/* Search for the RRSet in the node from the second tree. */
 		knot_rrset_t rrset = node_rrset_at(node, i);
 
-		/* SOAs are handled explicitely. */
+		/* SOAs are handled explicitly. */
 		if (rrset.type == KNOT_RRTYPE_SOA) {
 			continue;
 		}
@@ -292,7 +292,7 @@ static int knot_zone_diff_node(zone_node_t **node_ptr, void *data)
 		/* Search for the RRSet in the node from the second tree. */
 		knot_rrset_t rrset = node_rrset_at(node_in_second_tree, i);
 
-		/* SOAs are handled explicitely. */
+		/* SOAs are handled explicitly. */
 		if (rrset.type == KNOT_RRTYPE_SOA) {
 			continue;
 		}
diff --git a/src/knot/zone/zone.h b/src/knot/zone/zone.h
index 37621b4a1bdd00071f5828dd6f0d2bb3de781794..edacc00af41b2179a3496ad4e50f288f401bf5db 100644
--- a/src/knot/zone/zone.h
+++ b/src/knot/zone/zone.h
@@ -85,7 +85,7 @@ typedef struct zone
  *
  * \param name  Zone name.
  *
- * \return The initialized zone structure or NULL if an error occured.
+ * \return The initialized zone structure or NULL if an error occurred.
  */
 zone_t* zone_new(const knot_dname_t *name);
 
diff --git a/src/knot/zone/zonedb.h b/src/knot/zone/zonedb.h
index 4a6d301534058cfaa3509ed7891ba38ce5e45dc4..4a1d71ebfe31f7f163495d69ab2540a65618454d 100644
--- a/src/knot/zone/zonedb.h
+++ b/src/knot/zone/zonedb.h
@@ -72,7 +72,7 @@ typedef hhash_iter_t knot_zonedb_iter_t;
  * \brief Allocates and initializes the zone database structure.
  *
  * \return Pointer to the created zone database structure or NULL if an error
- *         occured.
+ *         occurred.
  */
 knot_zonedb_t *knot_zonedb_new(uint32_t size);
 
diff --git a/src/libknot/control/control.h b/src/libknot/control/control.h
index ad91cc05dd2ccf0058436780d67ff51336e64bfc..1411f45db810b4c2ad8efae6d1a092a633a09185 100644
--- a/src/libknot/control/control.h
+++ b/src/libknot/control/control.h
@@ -113,7 +113,7 @@ void knot_ctl_unbind(knot_ctl_t *ctx);
 int knot_ctl_connect(knot_ctl_t *ctx, const char *path);
 
 /*!
- * Waits for an incomming connection.
+ * Waits for an incoming connection.
  *
  * \note Server operation.
  *
diff --git a/src/libknot/dname.c b/src/libknot/dname.c
index 9bb5a2df594f1f75961ea0a0ad5f6c6ded4580fc..82160d6556b26ec2ad2d20a7319f47f92445321c 100644
--- a/src/libknot/dname.c
+++ b/src/libknot/dname.c
@@ -186,7 +186,7 @@ int knot_dname_unpack(uint8_t *dst, const knot_dname_t *src,
 	if (dst == NULL || src == NULL)
 		return KNOT_EINVAL;
 
-	/* Seek first real label occurence. */
+	/* Seek first real label occurrence. */
 	src = knot_wire_seek_label(src, pkt);
 
 	/* Unpack rest of the labels. */
@@ -668,7 +668,7 @@ int knot_dname_cmp_wire(const knot_dname_t *d1, const knot_dname_t *d2,
 	/* Convert to lookup format. */
 	uint8_t d1_lf[KNOT_DNAME_MAXLEN], d2_lf[KNOT_DNAME_MAXLEN];
 	if (knot_dname_lf(d1_lf, d1, pkt) < 0 || knot_dname_lf(d2_lf, d2, pkt) < 0) {
-		assert(0); /* This must not happend as the d1, d2 are checked. */
+		assert(0); /* This must not happened as the d1, d2 are checked. */
 		return KNOT_EINVAL;
 	}
 
@@ -732,7 +732,7 @@ int knot_dname_prefixlen(const uint8_t *name, unsigned nlabels, const uint8_t *p
 	if (nlabels == 0)
 		return 0;
 
-	/* Seek first real label occurence. */
+	/* Seek first real label occurrence. */
 	name = knot_wire_seek_label(name, pkt);
 
 	int len = 0;
diff --git a/src/libknot/dname.h b/src/libknot/dname.h
index a1934851901b157f0ea2d45eac14e0ce2196e714..6fd6fe7bded85902eb1f9621fc82d14ae8c4c00d 100644
--- a/src/libknot/dname.h
+++ b/src/libknot/dname.h
@@ -194,7 +194,7 @@ _pure_
 int knot_dname_size(const knot_dname_t *name);
 
 /*!
- * \brief Returns wire size of the given domain name (expaned compression ptrs).
+ * \brief Returns wire size of the given domain name (expanded compression ptrs).
  *
  * \param name Domain name to get the size of.
  * \param pkt Related packet (or NULL if unpacked)
diff --git a/src/libknot/packet/pkt.h b/src/libknot/packet/pkt.h
index 1748da4916252955c0493d0279f8635103d2f1c2..9e8754f0e10509623a400439aa146394e4e72db9 100644
--- a/src/libknot/packet/pkt.h
+++ b/src/libknot/packet/pkt.h
@@ -217,7 +217,7 @@ int knot_pkt_begin(knot_pkt_t *pkt, knot_section_t section_id);
  * \brief Put QUESTION in the packet.
  *
  * \note Since we support QD=1 only, QUESTION is a special type of packet section.
- * \note Must not be used after puting RRsets into the packet.
+ * \note Must not be used after putting RRsets into the packet.
  *
  * \param pkt
  * \param qname
diff --git a/src/libknot/rrset.h b/src/libknot/rrset.h
index 301c9364e731d57d55509f641b42de2b40dcd511..9a1b46b077152a68d1b918c01cada8d6782609b5 100644
--- a/src/libknot/rrset.h
+++ b/src/libknot/rrset.h
@@ -65,7 +65,7 @@ typedef enum {
  * \param type    TYPE of the RRSet.
  * \param rclass  CLASS of the RRSet.
  *
- * \return New RRSet structure or NULL if an error occured.
+ * \return New RRSet structure or NULL if an error occurred.
  */
 knot_rrset_t *knot_rrset_new(const knot_dname_t *owner, uint16_t type,
                              uint16_t rclass, knot_mm_t *mm);
@@ -161,7 +161,7 @@ bool knot_rrset_equal(const knot_rrset_t *r1, const knot_rrset_t *r2,
  */
 bool knot_rrset_empty(const knot_rrset_t *rrset);
 
-/* --------------------------- Miscelaneous --------------------------------- */
+/* --------------------------- Miscellaneous --------------------------------- */
 
 /*!
  * \brief Returns the TTL of the RRSet (of its first RR).
diff --git a/src/libknot/yparser/ypbody.c b/src/libknot/yparser/ypbody.c
index 22ec7bbfeca5db9c9862eb908b55f83520c19326..6adce6390461f722f1cb9725b273c41f8fb4b445 100644
--- a/src/libknot/yparser/ypbody.c
+++ b/src/libknot/yparser/ypbody.c
@@ -171,7 +171,7 @@ int _yp_parse(
 		p = parser->input.current;
 		pe = parser->input.end;
 		eof = NULL;
-	} else { // Set the last artifical block with just one new line char.
+	} else { // Set the last artificial block with just one new line char.
 		p = "\n";
 		pe = p + 1;
 		eof = pe;
diff --git a/src/libknot/yparser/ypbody.rl b/src/libknot/yparser/ypbody.rl
index 2d523bd0c9bc7fde07b71923a2436ab8aa5b919d..b7779d4a368c4659e7249c64acec2a030e41bc3a 100644
--- a/src/libknot/yparser/ypbody.rl
+++ b/src/libknot/yparser/ypbody.rl
@@ -179,7 +179,7 @@ int _yp_parse(
 		p = parser->input.current;
 		pe = parser->input.end;
 		eof = NULL;
-	} else { // Set the last artifical block with just one new line char.
+	} else { // Set the last artificial block with just one new line char.
 		p = "\n";
 		pe = p + 1;
 		eof = pe;
diff --git a/src/utils/common/netio.h b/src/utils/common/netio.h
index bbf00c5338116ac48fd123759d4ac24fee9bb432..e885e2c6a2c179f11587828bd3e0084c150d3c76 100644
--- a/src/utils/common/netio.h
+++ b/src/utils/common/netio.h
@@ -191,7 +191,7 @@ int net_send(const net_t *net, const uint8_t *buf, const size_t buf_len);
  * \brief Receives data from connected remote server.
  *
  * \param net		Connection parameters.
- * \param buf		Buffer for incomming data.
+ * \param buf		Buffer for incoming data.
  * \param buf_len	Length of the buffer.
  *
  * \retval >=0		length of successfully received data.
diff --git a/src/utils/knot1to2/extra.h b/src/utils/knot1to2/extra.h
index 97f93d4b414021323632a534e895cbabe6760500..c38de7acde0ab5cdba6674ceb7cc78fa92f0bf1b 100644
--- a/src/utils/knot1to2/extra.h
+++ b/src/utils/knot1to2/extra.h
@@ -51,7 +51,7 @@ typedef struct {
  *
  * \param file                Name of the main configuration file.
  *
- * \return Initialized stucture or NULL.
+ * \return Initialized structure or NULL.
  */
 conf_extra_t *conf_extra_init(const char *file, int run, share_t *share);
 
diff --git a/src/utils/knot1to2/includes.c b/src/utils/knot1to2/includes.c
index b170e650f412acd5600e2c4019bc0c6ff1a6ef10..0e0cefd4dd50fedd3f5ae97bb5db4aeecd34bec3 100644
--- a/src/utils/knot1to2/includes.c
+++ b/src/utils/knot1to2/includes.c
@@ -76,7 +76,7 @@ void conf_includes_free(conf_includes_t *includes)
  * e.g. path_relative_to("b.conf", "samples/a.conf") == "samples/b.conf"
  *
  * \param filename   File name of the target file.
- * \param reference  Referece file name (just path is used).
+ * \param reference  Reference file name (just path is used).
  *
  * \return Relative path to a reference file.
  */
diff --git a/src/zscanner/scanner.rl b/src/zscanner/scanner.rl
index 3b2ff8f77bd36e32db73f989e250a1ef67436ab5..0078efb52d318a0abd76a932ab360699149bd55f 100644
--- a/src/zscanner/scanner.rl
+++ b/src/zscanner/scanner.rl
@@ -449,7 +449,7 @@ int zs_parse_all(
 		parse(s);
 	}
 
-	// Check if any errors has occured.
+	// Check if any errors has occurred.
 	if (s->error.counter > 0) {
 		return -1;
 	}
diff --git a/src/zscanner/scanner_body.rl b/src/zscanner/scanner_body.rl
index aac6f43126fddee508967ec852f067bcb709df85..4f91ffe52fc7c38a168568c391abab14ef448539 100644
--- a/src/zscanner/scanner_body.rl
+++ b/src/zscanner/scanner_body.rl
@@ -188,7 +188,7 @@
 
 	# BEGIN - Domain name processing.
 	action _absolute_dname_exit {
-		// Enough room for the terminal label is garanteed (_label_exit).
+		// Enough room for the terminal label is guaranteed (_label_exit).
 		(s->dname)[s->dname_tmp_length++] = 0;
 	}
 	action _relative_dname_exit {
diff --git a/tests-extra/tests/dnssec/records/test.py b/tests-extra/tests/dnssec/records/test.py
index e9daa2f9a63792b66b02893caebea7d57f0e46cc..72bdacfd6b1ed9a3f1c8cad29b8566d9a3ca0ee7 100644
--- a/tests-extra/tests/dnssec/records/test.py
+++ b/tests-extra/tests/dnssec/records/test.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-'''Test for signing a zone with wierd records.'''
+'''Test for signing a zone with weird records.'''
 
 from dnstest.utils import *
 from dnstest.test import Test
diff --git a/tests-extra/tests/records/obsolete/data/obsolete.zone b/tests-extra/tests/records/obsolete/data/obsolete.zone
index 3df51365a0cbdafa34b763ea81ec17bbd652d4af..75aa489fdf28fb03f12cacc69a093c9aa2c9b573 100644
--- a/tests-extra/tests/records/obsolete/data/obsolete.zone
+++ b/tests-extra/tests/records/obsolete/data/obsolete.zone
@@ -15,7 +15,7 @@ dns2	A	192.0.2.2
 mail	A	192.0.2.3
 	AAAA	2001:DB8::3
 
-;obsolete-md	MD	domain-name1.	; Bind doens't support MD type,
+;obsolete-md	MD	domain-name1.	; Bind doesn't support MD type,
 ;obsolete-md	TYPE3	\# 0C646F6D61696E2D6E616D653100 ; neither this one
 ;obsolete-mf	MF	domain-name2.	; Bind doesn't support MF type,
 ;obsolete-mf	TYPE4	\# 0C646F6D61696E2D6E616D653200 ; neither this one
diff --git a/tests/confio.c b/tests/confio.c
index 13716f6cdfe1bad5885a6a740acec6b0e7b4771a..07c0011b3e9903c401f4195cd8a976d5f4324025 100644
--- a/tests/confio.c
+++ b/tests/confio.c
@@ -235,7 +235,7 @@ static void test_conf_io_abort()
 	conf_io_abort(false);
 	ok(conf()->io.txn == NULL, "check txn depth");
 
-	// Test child abort with commited subchild.
+	// Test child abort with committed subchild.
 	ok(conf_io_begin(false) == KNOT_EOK, "begin new parent txn");
 	ok(conf_io_begin(true) == KNOT_EOK, "begin child txn");
 	ok(conf_io_begin(true) == KNOT_EOK, "begin subchild txn");
diff --git a/tests/net_shortwrite.c b/tests/net_shortwrite.c
index 6979b2243693d0da5d9899862b48ca3d372b6526..daa54ea42ff683fe045c2efedc535a47642e1fb2 100644
--- a/tests/net_shortwrite.c
+++ b/tests/net_shortwrite.c
@@ -131,7 +131,7 @@ int main(int argc, char *argv[])
 	// receive message
 
 	r = pthread_join(thr, NULL);
-	ok(r == 0, "server: wait for reciever thread to terminate");
+	ok(r == 0, "server: wait for receiver thread to terminate");
 
 	ok(recv_data.result == sizeof(recvbuf) &&
 	   memcmp(sndbuf, recvbuf, sizeof(recvbuf)) == 0,
diff --git a/tests/zone_serial.c b/tests/zone_serial.c
index c300484a4018307ac7289b3559ef75dd24afbbed..b1cceb293590e9b1f449fe4aff397f8a5214a0a9 100644
--- a/tests/zone_serial.c
+++ b/tests/zone_serial.c
@@ -92,11 +92,11 @@ int main(int argc, char *argv[])
 
 	/* Corner-case: these serials' distance is exactly 2^31. */
 	uint32_t s1 = random_serial();
-	uint32_t s2 = s1 + S_ABOVE_MIDDLE;  // exactly the 'oposite' number
+	uint32_t s2 = s1 + S_ABOVE_MIDDLE;  // exactly the 'opposite' number
 	ok(serial_compare(s1, s2) < 0,
-	   "serial compare: random oposites (s1 < s2)");
+	   "serial compare: random opposites (s1 < s2)");
 	ok(serial_compare(s2, s1) < 0,
-	   "serial compare: random oposites (s2 < s1)");
+	   "serial compare: random opposites (s2 < s1)");
 
 	return 0;
 }
diff --git a/src/zscanner/scanner.h b/src/zscanner/scanner.h
index cd25841e6cf28e201ffbce3488ee62da3579270a..361f4da21ff2ab4f5401838d39d44dbcf7bf829f 100644
--- a/src/zscanner/scanner.h
+++ b/src/zscanner/scanner.h
@@ -88,7 +88,7 @@ typedef struct {
 typedef enum {
 	ZS_STATE_NONE,     /*!< Initial state. */
 	ZS_STATE_DATA,     /*!< A record parsed. */
-	ZS_STATE_ERROR,    /*!< An error occured. */
+	ZS_STATE_ERROR,    /*!< An error occurred. */
 	ZS_STATE_INCLUDE,  /*!< An include directive parsed. */
 	ZS_STATE_EOF,      /*!< The end of the current input reached. */
 	ZS_STATE_STOP      /*!< Finished parsing. */
@@ -97,7 +97,7 @@ typedef enum {
 /*!
  * \brief Context structure for zone scanner.
  *
- * This structure contains folowing items:
+ * This structure contains following items:
  *  - Copies of Ragel internal variables. The scanner can be called many times
  *    on smaller parts of zone file/memory. So it is necessary to preserve
  *    internal values between subsequent scanner callings.
@@ -106,7 +106,7 @@ typedef enum {
  *    can be used in callback functions.
  *  - Zone file and error information.
  *  - Output variables (r_ prefix) containing all parts of zone record. These
- *    data are usefull during processing via callback function.
+ *    data are useful during processing via callback function.
  */
 typedef struct scanner zs_scanner_t; // Forward declaration due to arguments.
 struct scanner {
@@ -215,7 +215,7 @@ struct scanner {
 	} file;
 
 	struct {
 		/*! Last occured error/warning code. */
 		int code;
 		/*! Error/warning counter. */
 		uint64_t counter;
@@ -215,7 +215,7 @@ struct scanner {
 
 	struct {
-		/*! Last occured error/warning code. */
+		/*! Last occurred error/warning code. */
 		int code;
 		/*! Error/warning counter. */